@@ -25,11 +25,11 @@ QUEUE_NAME_TIMESTAMP_FORMAT = "%Y%m%d%H%M%S"
 ALLOCATED_TIME = "allocated_time"
 JOB_ID = "job_id"
 LAST_UPDATE_TIME = "last_update_time"
-LOGICAL_CPU_ALLOCATED = "logical_cpu_allocated"
-LOGICAL_CPU_AVAILABLE = "logical_cpu_available"
-MEMORY_GB_ALLOCATED = "memory_gb_allocated"
-MEMORY_GB_AVAILABLE = "memory_gb_available"
+RESOURCES_AVAILABLE = "resources_available"
+NON_CONSUMABLE_RESOURCES = "non_consumable_resources"
+RESOURCES_ALLOCATED = "resources_allocated"
 RUNNING_JOBS = "running_jobs"
+PREVENT_FURTHER_ALLOCATION = "prevent_further_allocation"
 SINGLE_PARTITION_KEY = "_"
 VM_NAME = "vm_name"
 
